namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    
    [Serialized]
    [Weight(400)]                                          
    public partial class SalmonDinnerItem :
        FoodItem            
    {
        public override string FriendlyName                     { get { return "Salmon Dinner"; } }
        public override string Description                      { get { return "A full dinner of Breaded Salmon and Salad!"; } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 25, Fat = 14, Protein = 4, Vitamins = 10};
        public override float Calories                          { get { return 700; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CulinaryArtsSkill), 4)]    
    public partial class SalmonDinnerRecipe : Recipe
    {
        public SalmonDinnerRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<SalmonDinnerItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<SalmonItem>(typeof(CulinaryArtsEfficiencySkill), 5, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
		new CraftingElement<BasicSaladItem>(typeof(CulinaryArtsEfficiencySkill), 5, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
		new CraftingElement<FlourItem>(typeof(CulinaryArtsEfficiencySkill), 10, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
		new CraftingElement<OilItem>(typeof(CulinaryArtsEfficiencySkill), 10, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
		new CraftingElement<CornItem>(typeof(CulinaryArtsEfficiencySkill), 15, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(SalmonDinnerRecipe), Item.Get<SalmonDinnerItem>().UILink(), 9, typeof(CulinaryArtsSpeedSkill)); 
            this.Initialize("Salmon Dinner", typeof(SalmonDinnerRecipe));
            CraftingComponent.AddRecipe(typeof(StoveObject), this);
        }
    }
}